@@ -9,16 +9,20 @@ from tg.decorators import cached_property
 from photos import model
 from photos.model import DBSession, Gallery, Photo
 
-from repoze.what import predicates
 from tgext.crud import EasyCrudRestController
 
+try:
+    from tg import predicates
+except ImportError:
+    from repoze.what import predicates
+
 try:
     from tw2.forms import FileField
-    from formencode.validators import FieldStorageUploadConverter
+    from tw2.forms import FileValidator
     from tw2.core import Deferred
 except ImportError:
     from tw.forms import FileField
-    from tw.forms.validators import FieldStorageUploadConverter
+    from tw.forms.validators import FieldStorageUploadConverter as FileValidator
     def Deferred(f):
         return f
 
@@ -34,11 +38,12 @@ class PhotosController(EasyCrudRestController):
     title = "Manage Photos"
     model = model.Photo
     keep_params = ['gallery']
+    remember_values = ['image']
 
     __form_options__ = {
         '__hide_fields__' : ['uid', 'author', 'gallery'],
         '__field_widget_types__' : {'image':FileField},
-        '__field_validator_types__' : {'image':FieldStorageUploadConverter},
+        '__field_validator_types__' : {'image':FileValidator},
         '__field_widget_args__' : {'author':{'default':_get_current_user,
                                              'value':Deferred(_get_current_user)}}
     }
