@@ -3,7 +3,7 @@ from sqlalchemy.types import Unicode, Integer, DateTime
 from sqlalchemy.orm import backref, relation
 
 from photos.model import DeclarativeBase
-from tgext.pluggable import app_model, primary_key
+from tgext.pluggable import app_model, primary_key, plug_url
 
 from tgext.datahelpers.fields import Attachment, AttachedImage
 
@@ -26,3 +26,9 @@ class Photo(DeclarativeBase):
 
     gallery_id = Column(Integer, ForeignKey(Gallery.uid))
     gallery = relation(Gallery, backref=backref('photos', cascade='all, delete-orphan'))
+
+    def url(self, inline):
+        if inline:
+            return self.image.url
+        else:
+            return plug_url('photos', '/photo/%s' % self.uid)
